import objc
from PyObjCTools.TestSupport import TestCase, min_os_level
import MultipeerConnectivity


class TestMCNearbyServiceBrowser(TestCase):
    @min_os_level("10.10")
    def testClasses(self):
        self.assertIsInstance(
            MultipeerConnectivity.MCNearbyServiceBrowser, objc.objc_class
        )

    @min_os_level("10.10")
    def testProtocols(self):
        self.assertIsInstance(
            objc.protocolNamed("MCNearbyServiceBrowserDelegate"), objc.formal_protocol
        )



# This file is generated by objective.metadata
#
# Last update: Sun Feb 20 19:10:10 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$MCErrorDomain$kMCSessionMaximumNumberOfPeers@Q$kMCSessionMinimumNumberOfPeers@Q$"""
enums = """$MCEncryptionNone@2$MCEncryptionOptional@0$MCEncryptionRequired@1$MCErrorCancelled@5$MCErrorInvalidParameter@2$MCErrorNotConnected@1$MCErrorTimedOut@4$MCErrorUnavailable@6$MCErrorUnknown@0$MCErrorUnsupported@3$MCSessionSendDataReliable@0$MCSessionSendDataUnreliable@1$MCSessionStateConnected@2$MCSessionStateConnecting@1$MCSessionStateNotConnected@0$"""
misc.update(
    {
        "MCSessionState": NewType("MCSessionState", int),
        "MCEncryptionPreference": NewType("MCEncryptionPreference", int),
        "MCSessionSendDataMode": NewType("MCSessionSendDataMode", int),
        "MCErrorCode": NewType("MCErrorCode", int),
    }
)
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"MCSession",
        b"nearbyConnectionDataForPeer:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"MCSession",
        b"sendData:toPeers:withMode:error:",
        {"retval": {"type": b"Z"}, "arguments": {5: {"type_modifier": b"o"}}},
    )
    r(
        b"MCSession",
        b"sendResourceAtURL:withName:toPeer:withCompletionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"MCSession",
        b"startStreamWithName:toPeer:error:",
        {"arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"NSObject",
        b"advertiser:didNotStartAdvertisingPeer:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"advertiser:didReceiveInvitationFromPeer:withContext:invitationHandler:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"Z"},
                            2: {"type": b"@"},
                        },
                    },
                    "type": "@?",
                },
            },
        },
    )
    r(
        b"NSObject",
        b"advertiserAssistantDidDismissInvitation:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"advertiserAssistantWillPresentInvitation:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"browser:didNotStartBrowsingForPeers:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"browser:foundPeer:withDiscoveryInfo:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"browser:lostPeer:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"browserViewController:shouldPresentNearbyPeer:withDiscoveryInfo:",
        {
            "required": False,
            "retval": {"type": b"Z"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"browserViewControllerDidFinish:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"browserViewControllerWasCancelled:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"session:didFinishReceivingResourceWithName:fromPeer:atURL:withError:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {"type": b"@"},
                6: {"type": b"@"},
            },
        },
    )
    r(
        b"NSObject",
        b"session:didReceiveCertificate:fromPeer:certificateHandler:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"Z"}},
                    },
                    "type": "@?",
                },
            },
        },
    )
    r(
        b"NSObject",
        b"session:didReceiveData:fromPeer:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"session:didReceiveStream:withName:fromPeer:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {"type": b"@"},
            },
        },
    )
    r(
        b"NSObject",
        b"session:didStartReceivingResourceWithName:fromPeer:withProgress:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {"type": b"@"},
            },
        },
    )
    r(
        b"NSObject",
        b"session:peer:didChangeState:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": "Q"}},
        },
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



import objc
from PyObjCTools.TestSupport import TestCase, min_os_level
import MultipeerConnectivity


class TestMCSessionHelper(MultipeerConnectivity.NSObject):
    def session_didReceiveCertificate_fromPeer_certificateHandler_(self, s, c, p, h):
        pass

    def session_peer_didChangeState_(self, session, peer, state):
        pass


class TestMCSession(TestCase):
    @min_os_level("10.10")
    def testClasses(self):
        self.assertIsInstance(MultipeerConnectivity.MCSession, objc.objc_class)

    @min_os_level("10.10")
    def testMethods(self):
        self.assertResultIsBOOL(
            MultipeerConnectivity.MCSession.sendData_toPeers_withMode_error_
        )
        self.assertArgIsBlock(
            MultipeerConnectivity.MCSession.sendResourceAtURL_withName_toPeer_withCompletionHandler_,
            3,
            b"v@",
        )
        self.assertArgIsOut(
            MultipeerConnectivity.MCSession.startStreamWithName_toPeer_error_, 2
        )

        self.assertArgIsBlock(
            MultipeerConnectivity.MCSession.nearbyConnectionDataForPeer_withCompletionHandler_,
            1,
            b"v@@",
        )

    @min_os_level("10.10")
    def testProtocols(self):
        self.assertIsInstance(
            objc.protocolNamed("MCSessionDelegate"), objc.formal_protocol
        )

        self.assertArgHasType(
            TestMCSessionHelper.session_peer_didChangeState_, 2, objc._C_NSUInteger
        )

        self.assertArgIsBlock(
            TestMCSessionHelper.session_didReceiveCertificate_fromPeer_certificateHandler_,
            3,
            b"v" + objc._C_NSBOOL,
        )

    @min_os_level("10.10")
    def testConstants(self):
        self.assertEqual(MultipeerConnectivity.MCSessionSendDataReliable, 0)
        self.assertEqual(MultipeerConnectivity.MCSessionSendDataUnreliable, 1)
        self.assertEqual(MultipeerConnectivity.MCSessionStateNotConnected, 0)
        self.assertEqual(MultipeerConnectivity.MCSessionStateConnecting, 1)
        self.assertEqual(MultipeerConnectivity.MCSessionStateConnected, 2)
        self.assertEqual(MultipeerConnectivity.MCEncryptionOptional, 0)
        self.assertEqual(MultipeerConnectivity.MCEncryptionRequired, 1)
        self.assertEqual(MultipeerConnectivity.MCEncryptionNone, 2)
        self.assertIsInstance(MultipeerConnectivity.kMCSessionMinimumNumberOfPeers, int)
        self.assertIsInstance(MultipeerConnectivity.kMCSessionMaximumNumberOfPeers, int)



import objc
from PyObjCTools.TestSupport import TestCase, min_os_level
import MultipeerConnectivity


class TestMCNearbyServiceAdvertiserDelegateHelper(MultipeerConnectivity.NSObject):
    def advertiser_didReceiveInvitationFromPeer_withContext_invitationHandler_(
        self, adv, recv, ctx, hdlr
    ):
        pass


class TestMCNearbyServiceAdvertiser(TestCase):
    @min_os_level("10.10")
    def testClasses(self):
        self.assertIsInstance(
            MultipeerConnectivity.MCNearbyServiceAdvertiser, objc.objc_class
        )

    @min_os_level("10.10")
    def testProtocols(self):
        self.assertIsInstance(
            objc.protocolNamed("MCNearbyServiceAdvertiserDelegate"),
            objc.formal_protocol,
        )
        self.assertArgIsBlock(
            TestMCNearbyServiceAdvertiserDelegateHelper.advertiser_didReceiveInvitationFromPeer_withContext_invitationHandler_,
            3,
            b"v" + objc._C_NSBOOL + b"@",
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import MultipeerConnectivity


class TestMCError(TestCase):
    @min_os_level("10.10")
    def testContents(self):
        self.assertEqual(MultipeerConnectivity.MCErrorUnknown, 0)
        self.assertEqual(MultipeerConnectivity.MCErrorNotConnected, 1)
        self.assertEqual(MultipeerConnectivity.MCErrorInvalidParameter, 2)
        self.assertEqual(MultipeerConnectivity.MCErrorUnsupported, 3)
        self.assertEqual(MultipeerConnectivity.MCErrorTimedOut, 4)
        self.assertEqual(MultipeerConnectivity.MCErrorCancelled, 5)
        self.assertEqual(MultipeerConnectivity.MCErrorUnavailable, 6)
